imagesize: Getting image size from png/jpeg/jpeg2000/gif file
=============================================================

Description
-----------

Getting image size from png/jpeg/jpeg2000/gif file

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/imagesize/

